@@ -1,3 +1,3 @@
 from . import khtube
 
-khtube.khtube()
+# khtube.khtube()
